Crate kcr_jenkins_io

Crate kcr_jenkins_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the jenkins.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

jenkins.io/v1alpha2

  • Jenkins

Modules

v1alpha2